"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.send = send;

var _crypto = _interopRequireDefault(require("crypto"));

var _got = _interopRequireDefault(require("got"));

async function send({
  accessToken = process.env.D_ACCESS_TOKEN,
  secret = process.env.D_SECRET,
  title,
  content,
  at
}) {
  if (!accessToken) {
    throw new Error('accessToken 不能为空');
  }

  if (!secret) {
    throw new Error('secret 不能为空');
  }

  const timestamp = Date.now();

  const sign = _crypto.default.createHmac('sha256', secret).update(`${timestamp}\n${secret}`).digest('base64');

  const {
    body
  } = await _got.default.post('https://oapi.dingtalk.com/robot/send', {
    responseType: 'json',
    searchParams: {
      access_token: accessToken,
      timestamp: timestamp,
      sign: sign
    },
    json: {
      msgtype: 'markdown',
      markdown: {
        title: title,
        text: content
      },
      at: {
        atMobiles: Array.isArray(at) ? at : [],
        isAtAll: at === 'all'
      }
    }
  });

  if (body.errcode !== 0) {
    throw new Error(`[notify-dingtalk@send] ${body.errmsg}`);
  }

  return body;
}